@@ -1,6 +1,6 @@
 #! /bin/sh
 #
-# This is a kernel build script for Fedora Core 5's 2.6.20 kernel.
+# This is a kernel build script for Fedora Core 4's 2.6.17 kernel.
 #
 
 die () {
@@ -10,33 +10,33 @@ die () {
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 
-if [ ! -r kernel-2.6.20-1.2320.fc5.src.rpm ]
+if [ ! -r kernel-2.6.17-1.2142_FC4.src.rpm ]
 then
-    wget http://ftp.riken.jp/Linux/fedora/core/updates/5/SRPMS/kernel-2.6.20-1.2320.fc5.src.rpm || die "Can't download source package."
+    wget http://ftp.riken.go.jp/Linux/fedoralegacy/fedora/4/updates/SRPMS/kernel-2.6.17-1.2142_FC4.src.rpm || die "Can't download source package."
 fi
-rpm -ivh kernel-2.6.20-1.2320.fc5.src.rpm || die "Can't install source package."
+rpm -ivh kernel-2.6.17-1.2142_FC4.src.rpm || die "Can't install source package."
 
 cd /usr/src/redhat/SOURCES/ || die "Can't chdir to /usr/src/redhat/SOURCES/ ."
-if [ ! -r ccs-patch-1.6.8-20090824.tar.gz ]
+if [ ! -r ccs-patch-1.6.8-20090911.tar.gz ]
 then
-    wget http://osdn.dl.sourceforge.jp/tomoyo/30297/ccs-patch-1.6.8-20090824.tar.gz || die "Can't download patch."
+    wget http://osdn.dl.sourceforge.jp/tomoyo/30297/ccs-patch-1.6.8-20090911.tar.gz || die "Can't download patch."
 fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 cp -p /usr/src/redhat/SPECS/kernel-2.6.spec . || die "Can't copy spec file."
 patch << "EOF" || die "Can't patch spec file."
---- kernel-2.6.spec	2007-06-13 05:34:55.000000000 +0900
-+++ kernel-2.6.spec	2008-04-16 12:09:56.000000000 +0900
-@@ -33,7 +33,7 @@
- %define sublevel 20
+--- kernel-2.6.spec	2006-07-12 11:30:41.000000000 +0900
++++ kernel-2.6.spec	2008-04-16 12:23:17.000000000 +0900
+@@ -18,7 +18,7 @@
+ %define sublevel 17
  %define kversion 2.6.%{sublevel}
  %define rpmversion 2.6.%{sublevel}
--%define release %(R="$Revision: 1.2320 $"; RR="${R##: }"; echo ${RR%%?})%{?dist}
-+%define release %(R="$Revision: 1.2320 $"; RR="${R##: }"; echo ${RR%%?})%{?dist}.fc5_tomoyo_1.6.8p1
+-%define release %(R="$Revision: 1.2142 $"; RR="${R##: }"; echo ${RR%%?})_FC4
++%define release %(R="$Revision: 1.2142 $"; RR="${R##: }"; echo ${RR%%?})_FC4_tomoyo_1.6.8p1
  %define signmodules 0
- %define xen_hv_cset 11774
  %define make_target bzImage
-@@ -196,6 +196,9 @@
+ %define kernel_image x86
+@@ -119,6 +119,9 @@
  # to versions below the minimum
  #
  
@@ -46,28 +46,28 @@ patch << "EOF" || die "Can't patch spec file."
  #
  # First the general kernel 2.6 required versions as per
  # Documentation/Changes
-@@ -221,7 +224,7 @@
+@@ -145,7 +148,7 @@
  #
- %define kernel_prereq  fileutils, module-init-tools, initscripts >= 8.11.1-1, mkinitrd >= 4.2.21-1
+ %define kernel_prereq  fileutils, module-init-tools, initscripts >= 5.83, mkinitrd >= 4.2.15-1
  
 -Name: kernel
 +Name: ccs-kernel
  Group: System Environment/Kernel
  License: GPLv2
  Version: %{rpmversion}
-@@ -1208,6 +1211,11 @@
+@@ -729,6 +732,11 @@
  
  # END OF PATCH APPLICATIONS
  
 +# TOMOYO Linux
-+tar -zxf $RPM_SOURCE_DIR/ccs-patch-1.6.8-20090824.tar.gz
-+# sed -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -1.2320.fc5/" -- Makefile
-+patch -sp1 < patches/ccs-patch-2.6.20-fedora-core-5.diff
++tar -zxf %_sourcedir/ccs-patch-1.6.8-20090911.tar.gz
++# sed -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -1.2142_FC4/" -- Makefile
++patch -sp1 < patches/ccs-patch-2.6.17-fedora-core-4.diff
 +
  cp %{SOURCE10} Documentation/
  
  mkdir configs
-@@ -1226,6 +1234,9 @@
+@@ -740,6 +748,9 @@
  for i in *.config
  do
    mv $i .config
